========
Overview
========

Python wrapper to DataWarehouse Connect.

* Free software: ISC license

Installation
============

::

    pip install dwclib

You can also install the in-development version with::

    pip install https://github.com/jaj42/python-dwclib/archive/master.zip

